"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var path_1 = require("path");
var common_1 = require("./common");
var alert = function (res, message) { return res.alert({ message: message }); };
function processPackage(args) {
    var _this = this;
    return function (req, res) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var pkg;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    if (!req.path.source.endsWith(args.filename)) {
                        return [2, res.next()];
                    }
                    alert(res, "Retrieving latest version information...");
                    pkg = common_1.npm.pkg({ json: JSON.parse(req.text || '') });
                    return [4, pkg.updateVersions({
                            filter: function (name, version) { return version === 'latest'; },
                        })];
                case 1:
                    _a.sent();
                    alert(res, 'Updating [package.json] file');
                    pkg.json.name = req.variables.moduleName;
                    if (req.variables.template === 'platform') {
                        pkg.setFields('scripts', {
                            test: 'ts test',
                            tdd: 'ts test --watch',
                            lint: 'ts lint',
                            build: 'ts build $@',
                            'build-test': 'ts build --tsconfig=tsconfig.test $@',
                            prepare: 'ts prepare',
                        });
                    }
                    res.text = pkg.toJson();
                    res.done(args.done);
                    return [2];
            }
        });
    }); };
}
exports.processPackage = processPackage;
function saveFile(args) {
    var _this = this;
    if (args === void 0) { args = {}; }
    return function (req, res) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var _a, rename, dir, target;
        return tslib_1.__generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    _a = args.rename, rename = _a === void 0 ? [] : _a;
                    dir = req.variables.dir;
                    target = path_1.join(dir, req.path.target);
                    rename
                        .filter(function (item) { return target.endsWith(item.from); })
                        .forEach(function (item) {
                        target = target.substr(0, target.length - item.from.length);
                        target += item.to;
                    });
                    alert(res, "Saving: " + target);
                    return [4, common_1.fs.ensureDir(dir)];
                case 1:
                    _b.sent();
                    return [4, common_1.fs.writeFile(target, req.buffer)];
                case 2:
                    _b.sent();
                    res.done(args.done);
                    return [2];
            }
        });
    }); };
}
exports.saveFile = saveFile;
function npmInstall(args) {
    var _this = this;
    if (args === void 0) { args = {}; }
    return function (req, res) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var dir, pkg, ver, msg;
        return tslib_1.__generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    dir = req.variables.dir;
                    pkg = common_1.npm.pkg(dir);
                    ver = pkg.devDependencies['@uiharness/dev'];
                    msg = "\uD83C\uDF3C  Installing UIHarness v" + ver + "...";
                    alert(res, msg);
                    return [4, common_1.npm.install({ dir: dir })];
                case 1:
                    _a.sent();
                    res.done(args.done);
                    return [2];
            }
        });
    }); };
}
exports.npmInstall = npmInstall;
function runInitCommand(args) {
    var _this = this;
    return function (req, res) { return tslib_1.__awaiter(_this, void 0, void 0, function () {
        var _a, dir, template, cmd;
        return tslib_1.__generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    _a = req.variables, dir = _a.dir, template = _a.template;
                    alert(res, "Initializing...");
                    cmd = "cd " + dir + " && node node_modules/.bin/ui init --template=" + template;
                    return [4, common_1.exec.cmd.run(cmd, { silent: true })];
                case 1:
                    _b.sent();
                    res.done(args.done);
                    return [2];
            }
        });
    }); };
}
exports.runInitCommand = runInitCommand;
